DVec

Struct DVec 

pub struct DVec<T> { /* private fields */ }
A persistent vector of T elements. Persistent collections change the trade-off relative to ordinary collections: they are very cheap to clone, but more expensive to update. Behind the scenes, DVec instances that are cloned from one another will share some part of their representation.

You may be accustomed to persistent APIs in other languages, where each mutation operation returns a new collection instead of modifying the collection in place. The DVec type, in contrast, behaves roughly like an ordinary vector, except that you can cheaply clone it. If you want to get a new collection with a given mutation, but leave the existing collection alone, use clone:

let mut vec1 = DVec::new();
vec1.push(22);
let mut vec2 = vec1.clone();
vec2.push(44);
assert_eq!(vec1.len(), 1);
assert_eq!(vec2.len(), 2);

Implementations

Source

impl<T: Clone + Debug> DVec<T>

pub fn new() -> Self

pub fn get(&self, index: usize) -> Option<&T>

pub fn get_mut(&mut self, index: usize) -> Option<&mut T>

pub fn len(&self) -> usize

pub fn push(&mut self, element: T)